@@ -2,12 +2,10 @@ use std::borrow::Cow;
 use std::ffi::OsStr;
 use std::iter::FusedIterator;
 use std::path::{Path, PathBuf};
-use std::process::Stdio;
 
 use anyhow::{Context, Result, anyhow};
 use pinyin::ToPinyin;
 use rand::Rng;
-use tokio::process::{Child, Command};
 use unicode_segmentation::UnicodeSegmentation;
 
 use crate::config::ServerOverlay;
@@ -100,7 +98,7 @@ pub fn get_app_new_database_path() -> Result<PathBuf> {
     Ok(db_path)
 }
 
-/// Get the podcast directoy resolved and created
+/// Get the podcast directory resolved and created
 fn get_podcast_save_path(config: &ServerOverlay) -> Result<PathBuf> {
     let full_path = shellexpand::path::tilde(&config.settings.podcast.download_dir);
     if !full_path.exists() {
@@ -192,35 +190,6 @@ impl StringUtils for String {
     }
 }
 
-/// Spawn a detached process
-/// # Panics
-/// panics when spawn server failed
-pub fn spawn_process<A: IntoIterator<Item = S> + Clone, S: AsRef<OsStr>>(
-    prog: &Path,
-    superuser: bool,
-    shout_output: bool,
-    args: A,
-) -> std::io::Result<Child> {
-    let mut cmd = if superuser {
-        let mut cmd_t = Command::new("sudo");
-        cmd_t.arg(prog);
-        cmd_t
-    } else {
-        Command::new(prog)
-    };
-    cmd.stdin(Stdio::null());
-    if shout_output {
-        cmd.stdout(Stdio::piped());
-        cmd.stderr(Stdio::piped());
-    } else {
-        cmd.stdout(Stdio::null());
-        cmd.stderr(Stdio::null());
-    }
-
-    cmd.args(args);
-    cmd.spawn()
-}
-
 /// Absolutize a given path with the current working directory.
 ///
 /// This function, unlike [`std::fs::canonicalize`] does *not* hit the filesystem and so does not require the input path to exist yet.
@@ -240,7 +209,7 @@ pub fn absolute_path(path: &Path) -> std::io::Result<Cow<'_, Path>> {
 
 /// Absolutize a given path with the given base.
 ///
-/// `base` is expected to be absoulte!
+/// `base` is expected to be absolute!
 ///
 /// This function, unlike [`std::fs::canonicalize`] does *not* hit the filesystem and so does not require the input path to exist yet.
 ///
