@@ -31,9 +31,13 @@ use termusiclib::config::SharedServerSettings;
 use termusiclib::track::{MediaTypes, Track};
 use tokio::runtime::Handle;
 use tokio::select;
+use tokio::sync::oneshot;
 
 use crate::backends::rusty::decoder::SymphoniaDecoderError;
-use crate::{MediaInfo, PlayerCmd, PlayerProgress, PlayerTrait, Speed, Volume};
+use crate::{
+    MediaInfo, PlayerCmd, PlayerCmdCallbackSender, PlayerCmdSender, PlayerProgress, PlayerTrait,
+    Speed, Volume,
+};
 use decoder::buffered_source::BufferedSource;
 use decoder::read_seek_source::ReadSeekSource;
 use decoder::{MediaTitleRx, MediaTitleType, Symphonia};
@@ -49,10 +53,10 @@ pub(crate) mod source;
 pub type TotalDuration = Option<Duration>;
 pub type ArcTotalDuration = Arc<Mutex<TotalDuration>>;
 
-#[derive(Clone, Debug)]
+#[derive(Debug)]
 enum PlayerInternalCmd {
     /// Enqueue a new track to be played, and if `enqueue: false` directly skip to it.
-    Play(Box<Track>, QueueNextOptions),
+    Play(Box<Track>, QueueNextOptions, PlayerCmdCallbackSender),
     Progress(Duration),
     Resume,
     SeekAbsolute(Duration),
@@ -64,6 +68,7 @@ enum PlayerInternalCmd {
     Volume(u16),
     Eos,
 }
+
 pub struct RustyBackend {
     volume: Arc<AtomicU16>,
     speed: i32,
@@ -137,8 +142,8 @@ impl RustyBackend {
 
     #[allow(clippy::needless_pass_by_value)]
     fn command(&self, cmd: PlayerInternalCmd) {
-        if let Err(e) = self.command_tx.send(cmd.clone()) {
-            error!("error in {cmd:?}: {e}");
+        if let Err(e) = self.command_tx.send(cmd) {
+            error!("error in {:?}: {e}", e.0);
         }
     }
 }
@@ -146,40 +151,47 @@ impl RustyBackend {
 #[async_trait]
 impl PlayerTrait for RustyBackend {
     async fn add_and_play(&mut self, track: &Track) {
-        let config_read = self.config.read_recursive();
-        let soundtouch = config_read.settings.backends.rusty.soundtouch;
-        let file_buf_size = usize::try_from(
-            config_read
-                .settings
-                .backends
-                .rusty
-                .file_buffer_size
-                .as_u64(),
-        )
-        .unwrap_or(usize::MAX);
-        let ringbuf_size = usize::try_from(
-            config_read
-                .settings
-                .backends
-                .rusty
-                .decoded_buffer_size
-                .as_u64(),
-        )
-        .unwrap_or(usize::MAX);
+        // this has to be a extra scope as rust does not see "drop(config_read)" as a drop and complains with:
+        // "await occurs here (rx.await), with `config_read` maybe used later"
+        let query_options = {
+            let config_read = self.config.read_recursive();
+            let soundtouch = config_read.settings.backends.rusty.soundtouch;
+            let file_buf_size = usize::try_from(
+                config_read
+                    .settings
+                    .backends
+                    .rusty
+                    .file_buffer_size
+                    .as_u64(),
+            )
+            .unwrap_or(usize::MAX);
+            let ringbuf_size = usize::try_from(
+                config_read
+                    .settings
+                    .backends
+                    .rusty
+                    .decoded_buffer_size
+                    .as_u64(),
+            )
+            .unwrap_or(usize::MAX);
 
-        drop(config_read);
-
-        self.command(PlayerInternalCmd::Play(
-            Box::new(track.clone()),
             QueueNextOptions {
                 gapless_decode: self.gapless,
                 soundtouch,
                 file_buf_size,
                 ringbuf_size,
                 enqueue: false,
-            },
+            }
+        };
+
+        let (tx, rx) = oneshot::channel::<()>();
+        self.command(PlayerInternalCmd::Play(
+            Box::new(track.clone()),
+            query_options,
+            PlayerCmdCallbackSender(Some(tx)),
         ));
         self.resume();
+        let _ = rx.await;
     }
 
     fn volume(&self) -> Volume {
@@ -284,6 +296,7 @@ impl PlayerTrait for RustyBackend {
                 ringbuf_size,
                 enqueue: true,
             },
+            PlayerCmdCallbackSender(None),
         ));
     }
 
@@ -561,10 +574,17 @@ fn append_to_sink_queue_no_duration(
 }
 
 /// Common handling of a `media_title` for a [`append_to_sink`] function
-fn common_media_title_cb(media_title: Arc<Mutex<String>>) -> impl Fn(MediaTitleType) {
-    move |cmd| match cmd {
-        MediaTitleType::Reset => media_title.lock().clear(),
-        MediaTitleType::Value(v) => *media_title.lock() = v,
+fn common_media_title_cb(
+    media_title: Arc<Mutex<String>>,
+    pcmd_tx: &PlayerCmdSender,
+) -> impl Fn(MediaTitleType) + use<> {
+    let pcmd_tx = pcmd_tx.clone();
+    move |cmd| {
+        match cmd {
+            MediaTitleType::Reset => media_title.lock().clear(),
+            MediaTitleType::Value(v) => *media_title.lock() = v,
+        }
+        let _ = pcmd_tx.send(PlayerCmd::MetadataChanged);
     }
 }
 
@@ -575,7 +595,7 @@ struct PlayerThreadArgs {
     pcmd_tx: crate::PlayerCmdSender,
     /// Internal Player commands that need to be processed by the player task
     picmd_tx: Sender<PlayerInternalCmd>,
-    /// Reciever for the Internal Player Command
+    /// Receiver for the Internal Player Command
     picmd_rx: Receiver<PlayerInternalCmd>,
     media_title: Arc<Mutex<String>>,
     // radio_downloaded: Arc<Mutex<u64>>,
@@ -622,7 +642,7 @@ async fn player_thread(mut args: PlayerThreadArgs) {
         };
 
         match cmd {
-            PlayerInternalCmd::Play(track, options) => {
+            PlayerInternalCmd::Play(track, options, cb) => {
                 if let Err(err) = queue_next(
                     &track,
                     &sink,
@@ -632,6 +652,7 @@ async fn player_thread(mut args: PlayerThreadArgs) {
                     &mut next_duration_opt,
                     &args.media_title,
                     // &radio_downloaded,
+                    &args.pcmd_tx,
                 )
                 .await
                 {
@@ -647,6 +668,8 @@ async fn player_thread(mut args: PlayerThreadArgs) {
                             .send(PlayerCmd::Error(crate::PlayerErrorType::Current));
                     }
                 }
+                // maybe this should be called by the source / decoder to be fully correct
+                cb.call();
             }
             PlayerInternalCmd::TogglePause => {
                 sink.toggle_playback();
@@ -766,6 +789,7 @@ async fn queue_next(
     total_duration: &ArcTotalDuration,
     next_duration_opt: &mut Option<Duration>,
     media_title: &Arc<Mutex<String>>,
+    pcmd_tx: &PlayerCmdSender,
 ) -> Result<()> {
     // clear out the sources when we dont "enqueue" as we want to directly play it
     if !options.enqueue && !sink.is_empty() {
@@ -793,7 +817,7 @@ async fn queue_next(
                         async_decode: true,
                     },
                     next_duration_opt,
-                    common_media_title_cb(media_title.clone()),
+                    common_media_title_cb(media_title.clone(), pcmd_tx),
                 )?;
             } else {
                 append_to_sink(
@@ -807,7 +831,7 @@ async fn queue_next(
                         async_decode: true,
                     },
                     total_duration,
-                    common_media_title_cb(media_title.clone()),
+                    common_media_title_cb(media_title.clone(), pcmd_tx),
                 )?;
             }
 
@@ -850,6 +874,7 @@ async fn queue_next(
 
             let media_title_clone = media_title.clone();
 
+            let pcmd_tx = pcmd_tx.clone();
             let cb = move |title: &str| {
                 let new_title = if title.is_empty() {
                     "<no title>".to_string()
@@ -858,6 +883,7 @@ async fn queue_next(
                 };
 
                 *media_title_clone.lock() = new_title;
+                let _ = pcmd_tx.send(PlayerCmd::MetadataChanged);
             };
 
             // set initial title to what the header says
@@ -921,7 +947,7 @@ async fn queue_next(
                             async_decode: true,
                         },
                         next_duration_opt,
-                        common_media_title_cb(media_title.clone()),
+                        common_media_title_cb(media_title.clone(), pcmd_tx),
                     )?;
                 } else {
                     append_to_sink(
@@ -935,7 +961,7 @@ async fn queue_next(
                             async_decode: true,
                         },
                         total_duration,
-                        common_media_title_cb(media_title.clone()),
+                        common_media_title_cb(media_title.clone(), pcmd_tx),
                     )?;
                 }
                 return Ok(());
@@ -967,7 +993,7 @@ async fn queue_next(
                         async_decode: false,
                     },
                     next_duration_opt,
-                    common_media_title_cb(media_title.clone()),
+                    common_media_title_cb(media_title.clone(), pcmd_tx),
                 )?;
             } else {
                 append_to_sink(
@@ -981,7 +1007,7 @@ async fn queue_next(
                         async_decode: false,
                     },
                     total_duration,
-                    common_media_title_cb(media_title.clone()),
+                    common_media_title_cb(media_title.clone(), pcmd_tx),
                 )?;
             }
             Ok(())
