@@ -3,7 +3,7 @@ use std::sync::mpsc::{self, Receiver};
 use base64::Engine;
 use souvlaki::{MediaControlEvent, MediaControls, MediaMetadata, MediaPlayback, PlatformConfig};
 use termusiclib::{
-    library_db::const_unknown::{UNKNOWN_ARTIST, UNKNOWN_TITLE},
+    common::const_unknown::{UNKNOWN_ARTIST, UNKNOWN_TITLE},
     track::Track,
 };
 
@@ -219,11 +219,16 @@ impl GeneralPlayer {
                 if volume > 1.0 {
                     error!("SetVolume above 1.0 will be clamped to 1.0!");
                 }
-                // convert a 0.0 to 1.0 range to 0 to 100, because that is what termusic uses for volume
-                // default float to int casting will truncate values to the decimal point
+                // convert a 0.0 to 1.0 range to 0 to 100, because that is what termusic uses for volume.
+                let clamp_100 = volume.clamp(0.0, 1.0) * 100.0;
+                // Default float to int casting will truncate values to the decimal point,
+                // so we round instead.
+                // For example "volume: 0.5000" plus "playerctl volume 0.1+" results in "0.15000", but doing
+                // "playerctl volume 0.1-" now, results in "0.49999", so if we dont round we would get "Volume: 4".
                 #[allow(clippy::cast_possible_truncation, clippy::cast_sign_loss)]
-                let uvol = (volume.clamp(0.0, 1.0) * 100.0) as u16;
-                self.set_volume(uvol);
+                let uvol = clamp_100.round() as u16;
+                // ignore error if sending failed
+                self.cmd_tx.send(PlayerCmd::VolumeSet(uvol)).ok();
             }
             MediaControlEvent::Quit => {
                 // ignore error if sending failed
@@ -292,7 +297,7 @@ mod windows {
 
             let handle_result = unsafe {
                 let instance = GetModuleHandleW(None)
-                    .map_err(|e| (format!("Getting module handle failed: {e}")))?;
+                    .map_err(|e| format!("Getting module handle failed: {e}"))?;
 
                 let wnd_class = WNDCLASSEXW {
                     cbSize: mem::size_of::<WNDCLASSEXW>() as u32,
