@@ -23,14 +23,14 @@
  */
 use anyhow::Result;
 use termusiclib::config::{SharedTuiSettings, TuiOverlay};
-use termusiclib::ids::{Id, IdConfigEditor};
-use termusiclib::types::{ConfigEditorMsg, Msg};
 use tui_realm_stdlib::{Radio, Span};
 use tuirealm::props::{Alignment, BorderSides, BorderType, Borders, Style, TextSpan};
 use tuirealm::{Component, Event, MockComponent};
 
 use super::popups::{YNConfirm, YNConfirmStyle};
+use crate::ui::ids::{Id, IdConfigEditor};
 use crate::ui::model::{ConfigEditorLayout, Model, UserEvent};
+use crate::ui::msg::{ConfigEditorMsg, Msg};
 
 mod color;
 mod general;
@@ -52,7 +52,7 @@ impl CEHeader {
                         .modifiers(BorderType::Plain)
                         .sides(BorderSides::BOTTOM),
                 )
-                .choices(&[
+                .choices([
                     "General Configuration",
                     "Themes and Colors",
                     "Keys Global",
@@ -84,7 +84,7 @@ pub struct CEFooter {
 impl CEFooter {
     pub fn new(config: &TuiOverlay) -> Self {
         Self {
-            component: Span::default().spans(&[
+            component: Span::default().spans([
                 TextSpan::new(" Save parameters: ").bold(),
                 TextSpan::new(format!("<{}>", config.settings.keys.config_keys.save))
                     .bold()
