@@ -1,144 +1,109 @@
-//! SPDX-License-Identifier: MIT
+use std::path::{Path, PathBuf};
+use std::time::Duration;
 
-use std::path::Path;
-use std::time::{Duration, Instant};
-
-use anyhow::{bail, Result};
-use termusiclib::config::SharedTuiSettings;
-use termusiclib::ids::{Id, IdConfigEditor, IdTagEditor};
-use termusiclib::types::{DBMsg, Msg, PCMsg};
+use anyhow::{Result, bail};
 use termusiclib::utils::get_parent_folder;
-use tui_realm_treeview::Tree;
+use tokio::runtime::Handle;
+use tokio::sync::mpsc::UnboundedReceiver;
+use tuirealm::EventListenerCfg;
 use tuirealm::props::{AttrValue, Attribute, Color, PropPayload, PropValue, TextSpan};
 use tuirealm::ratatui::layout::{Constraint, Layout};
 use tuirealm::ratatui::widgets::Clear;
-use tuirealm::EventListenerCfg;
 use tuirealm::{Frame, State, StateValue};
 
+use crate::ui::Application;
 use crate::ui::components::{
-    DBListCriteria, DBListSearchResult, DBListSearchTracks, DownloadSpinner, EpisodeList,
-    FeedsList, Footer, GSInputPopup, GSTablePopup, GlobalListener, LabelSpan, Lyric, MusicLibrary,
-    Playlist, Progress, Source,
+    DBListCriteria, DownloadSpinner, EpisodeList, FeedsList, Footer, GSInputPopup, GSTablePopup,
+    LabelSpan, Lyric, Playlist, Progress, Source,
 };
+use crate::ui::ids::{Id, IdConfigEditor, IdTagEditor};
+use crate::ui::model::ports::rx_main::PortRxMain;
+use crate::ui::model::ports::stream_events::PortStreamEvents;
 use crate::ui::model::{Model, TermusicLayout, UserEvent};
+use crate::ui::msg::{Msg, PCMsg};
 use crate::ui::utils::{
     draw_area_in_absolute, draw_area_in_relative, draw_area_top_right_absolute,
 };
-use crate::ui::Application;
 
 impl Model {
-    #[allow(clippy::too_many_lines)]
     pub fn init_app(
-        tree: &Tree<String>,
-        config: &SharedTuiSettings,
+        tx_to_main: UnboundedReceiver<Msg>,
+        stream_event_port: PortStreamEvents,
     ) -> Application<Id, Msg, UserEvent> {
         // Setup application
-
-        let mut app: Application<Id, Msg, UserEvent> = Application::init(
+        Application::init(
             EventListenerCfg::default()
-                .crossterm_input_listener(Duration::from_millis(20), 20)
-                .poll_timeout(Duration::from_millis(10))
-                .tick_interval(Duration::from_secs(1)),
-        );
-
-        Self::mount_main(&mut app, config, tree).unwrap();
-
-        // Mount global hotkey listener
-        assert!(app
-            .mount(
-                Id::GlobalListener,
-                Box::new(GlobalListener::new(config.clone())),
-                Self::subscribe(&config.read().settings.keys),
-            )
-            .is_ok());
-        // Active library
-        assert!(app.active(&Id::Library).is_ok());
-        app
+                .with_handle(Handle::current())
+                .async_crossterm_input_listener(Duration::ZERO, 10)
+                .poll_timeout(Duration::from_secs(10))
+                .async_tick(true)
+                .tick_interval(Duration::from_secs(1))
+                .add_async_port(Box::new(PortRxMain::new(tx_to_main)), Duration::ZERO, 10)
+                .add_async_port(Box::new(stream_event_port), Duration::ZERO, 1),
+        )
     }
 
-    /// Mount the Main components for the TUI
-    fn mount_main(
-        app: &mut Application<Id, Msg, UserEvent>,
-        config: &SharedTuiSettings,
-        tree: &Tree<String>,
-    ) -> Result<()> {
-        app.mount(
-            Id::Library,
-            Box::new(MusicLibrary::new(tree, None, config.clone())),
-            Vec::new(),
-        )?;
-        app.mount(
-            Id::DBListCriteria,
-            Box::new(DBListCriteria::new(
-                config.clone(),
-                Msg::DataBase(DBMsg::CriteriaBlurDown),
-                Msg::DataBase(DBMsg::CriteriaBlurUp),
-            )),
-            Vec::new(),
-        )?;
+    /// Mount the Main components for the TUI.
+    pub fn mount_main(&mut self) -> Result<()> {
+        self.remount_global_listener()?;
 
-        app.mount(
-            Id::DBListSearchResult,
-            Box::new(DBListSearchResult::new(
-                config.clone(),
-                Msg::DataBase(DBMsg::SearchResultBlurDown),
-                Msg::DataBase(DBMsg::SearchResultBlurUp),
-            )),
-            Vec::new(),
-        )?;
-        app.mount(
-            Id::DBListSearchTracks,
-            Box::new(DBListSearchTracks::new(
-                config.clone(),
-                Msg::DataBase(DBMsg::SearchTracksBlurDown),
-                Msg::DataBase(DBMsg::SearchTracksBlurUp),
-            )),
-            Vec::new(),
-        )?;
-        app.mount(
+        self.mount_library()?;
+        self.remount_database_search()?;
+
+        self.app.mount(
             Id::Playlist,
-            Box::new(Playlist::new(config.clone())),
+            Box::new(Playlist::new(self.config_tui.clone())),
             Vec::new(),
         )?;
-        app.mount(
+        self.app.mount(
             Id::Progress,
-            Box::new(Progress::new(&config.read())),
+            Box::new(Progress::new(&self.config_tui.read())),
+            Vec::new(),
+        )?;
+        self.app.mount(
+            Id::Lyric,
+            Box::new(Lyric::new(self.config_tui.clone())),
             Vec::new(),
         )?;
-        app.mount(Id::Lyric, Box::new(Lyric::new(config.clone())), Vec::new())?;
 
-        app.mount(
+        self.app.mount(
             Id::Podcast,
             Box::new(FeedsList::new(
-                config.clone(),
+                self.config_tui.clone(),
                 Msg::Podcast(PCMsg::PodcastBlurDown),
                 Msg::Podcast(PCMsg::PodcastBlurUp),
             )),
             Vec::new(),
         )?;
 
-        app.mount(
+        self.app.mount(
             Id::Episode,
             Box::new(EpisodeList::new(
-                config.clone(),
+                self.config_tui.clone(),
                 Msg::Podcast(PCMsg::EpisodeBlurDown),
                 Msg::Podcast(PCMsg::EpisodeBlurUp),
             )),
             Vec::new(),
         )?;
-        app.mount(
+        self.app.mount(
             Id::DownloadSpinner,
-            Box::new(DownloadSpinner::new(&config.read())),
+            Box::new(DownloadSpinner::new(&self.config_tui.read())),
             Vec::new(),
         )?;
 
+        self.mount_label_help();
+
+        // Set the Library component as the initally focused one
+        self.app.active(&Id::Library)?;
+
         Ok(())
     }
 
+    /// The entrypoint to start drawing the full TUI, if a redraw is requested.
     pub fn view(&mut self) {
         if self.redraw {
             self.redraw = false;
-            self.last_redraw = Instant::now();
+
             if self
                 .app
                 .mounted(&Id::TagEditor(IdTagEditor::TableLyricOptions))
@@ -377,7 +342,7 @@ impl Model {
         self.app
             .remount(
                 Id::GeneralSearchInput,
-                Box::new(GSInputPopup::new(source, &self.config_tui.read())),
+                Box::new(GSInputPopup::new(source.clone(), &self.config_tui.read())),
                 Vec::new(),
             )
             .unwrap();
@@ -396,8 +361,8 @@ impl Model {
     }
 
     #[inline]
-    pub fn mount_search_library(&mut self) {
-        self.mount_search(Source::Library);
+    pub fn mount_search_library(&mut self, path: PathBuf) {
+        self.mount_search(Source::Library(path));
     }
 
     #[inline]
@@ -465,7 +430,7 @@ impl Model {
         Ok(())
     }
 
-    pub fn show_message_timeout_label_help<S: AsRef<str>>(
+    pub fn show_message_timeout_label_help<S: Into<String>>(
         &mut self,
         active_msg: S,
         foreground: Option<Color>,
